Package: biomartr
Title: Genomic Data Retrieval
Version: 1.0.7
Authors@R: c(person("Hajk-Georg", "Drost",
                role = c("aut", "cre"),
                email = "hajk-georg.drost@tuebingen.mpg.de",
                comment = c(ORCID = "http://orcid.org/0000-0002-1567-306X")),
                person("Haakon", "Tjeldnes", 
                email = "hauken_heyken@hotmail.com", 
                role = c("aut", "ctb"))
                )
Description: Perform large scale genomic data retrieval and functional annotation retrieval. This package aims to provide users with a standardized
                way to automate genome, proteome, 'RNA', coding sequence ('CDS'), 'GFF', and metagenome
                retrieval from 'NCBI RefSeq', 'NCBI Genbank', 'ENSEMBL', 
                and 'UniProt' databases. Furthermore, an interface to the 'BioMart' database
                (Smedley et al. (2009) <doi:10.1186/1471-2164-10-22>) allows users to retrieve
                functional annotation for genomic loci. In addition, users can download entire databases such
                as 'NCBI RefSeq' (Pruitt et al. (2007) <doi:10.1093/nar/gkl842>), 'NCBI nr',
                'NCBI nt', 'NCBI Genbank' (Benson et al. (2013) <doi:10.1093/nar/gks1195>), etc. with only one command.
VignetteBuilder: knitr
NeedsCompilation: yes
Depends: R (>= 3.1.1)
Imports: biomaRt, Biostrings, curl, tibble, jsonlite, data.table (>=
        1.9.4), dplyr (>= 0.3.0), readr (>= 1.4.0), downloader (>=
        0.3), RCurl (>= 1.95-4.5), XML (>= 3.98-1.1), httr (>= 0.6.1),
        stringr (>= 0.6.2), purrr, R.utils, philentropy, withr, fs
Suggests: knitr (>= 1.6), rmarkdown (>= 0.3.3), devtools (>= 1.6.1),
        testthat, seqinr, magrittr
License: GPL-2
URL: https://docs.ropensci.org/biomartr/,
        https://github.com/ropensci/biomartr
BugReports: https://github.com/ropensci/biomartr/issues
RoxygenNote: 7.2.3
Encoding: UTF-8
X-schema.org-keywords: BioMart, genomic-data-retrieval,
        annotation-retrieval, database-retrieval, NCBI, ENSEMBL,
        biological-data-retrieval
X-schema.org-applicationCategory: Data Access
X-schema.org-isPartof: "ropensci.org"
Packaged: 2023-12-02 14:46:32 UTC; hdrost
Author: Hajk-Georg Drost [aut, cre] (<https://orcid.org/0000-0002-1567-306X>),
  Haakon Tjeldnes [aut, ctb]
Maintainer: Hajk-Georg Drost <hajk-georg.drost@tuebingen.mpg.de>
Repository: CRAN
Date/Publication: 2023-12-02 17:40:07 UTC
Built: R 4.6.0; ; 2026-04-29 12:17:06 UTC; unix
