# Generated by roxygen2: do not edit by hand

export(biomart)
export(cachedir)
export(cachedir_set)
export(check_annotation_biomartr)
export(download.database)
export(download.database.all)
export(ensembl_divisions)
export(get.ensembl.info)
export(getAssemblyStats)
export(getAttributes)
export(getBioSet)
export(getCDS)
export(getCDSSet)
export(getCollection)
export(getCollectionSet)
export(getDatasets)
export(getENSEMBLGENOMESInfo)
export(getENSEMBLInfo)
export(getFilters)
export(getGENOMEREPORT)
export(getGFF)
export(getGFFSet)
export(getGO)
export(getGTF)
export(getGenome)
export(getGenomeSet)
export(getGroups)
export(getKingdomAssemblySummary)
export(getKingdoms)
export(getMarts)
export(getMetaGenomeAnnotations)
export(getMetaGenomeSummary)
export(getMetaGenomes)
export(getProteome)
export(getProteomeSet)
export(getRNA)
export(getRNASet)
export(getReleases)
export(getRepeatMasker)
export(getSummaryFile)
export(getUniProtInfo)
export(getUniProtSTATS)
export(is.genome.available)
export(listDatabases)
export(listGenomes)
export(listGroups)
export(listKingdoms)
export(listMetaGenomes)
export(listNCBIDatabases)
export(meta.retrieval)
export(meta.retrieval.all)
export(organismAttributes)
export(organismBM)
export(organismFilters)
export(read_assemblystats)
export(read_cds)
export(read_genome)
export(read_gff)
export(read_proteome)
export(read_rm)
export(read_rna)
export(refseqOrganisms)
export(summary_cds)
export(summary_genome)
import(Biostrings)
import(RCurl)
import(biomaRt)
import(curl)
importFrom(RCurl,url.exists)
importFrom(XML,getHTMLLinks)
importFrom(data.table,":=")
importFrom(data.table,.BY)
importFrom(data.table,.EACHI)
importFrom(data.table,.GRP)
importFrom(data.table,.I)
importFrom(data.table,.N)
importFrom(data.table,.NGRP)
importFrom(data.table,.SD)
importFrom(data.table,chmatch)
importFrom(data.table,data.table)
importFrom(data.table,fread)
importFrom(data.table,fwrite)
importFrom(data.table,rbindlist)
