please_cite_biomartr <- function(mute_citation = FALSE) {
  if (!mute_citation) {
    cat("\n")
    cat("\n")
    cat("Please cite: Drost HG, Paszkowski J. Biomartr: genomic data retrieval with R. Bioinformatics (2017) 33(8): 1216-1217. doi:10.1093/bioinformatics/btw821.")
    cat("\n")
  }
}