% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getENSEMBLGENOMES.R
\name{getENSEMBLGENOMESInfo}
\alias{getENSEMBLGENOMESInfo}
\title{Retrieve ENSEMBLGENOMES info file}
\usage{
getENSEMBLGENOMESInfo()
}
\description{
Retrieve species and genome information from
http://rest.ensemblgenomes.org/info/species?content-type=application/json/.
}
\examples{
\dontrun{
info.file <- getENSEMBLGENOMESInfo()
info.file
}
}
\author{
Hajk-Georg Drost
}
